# CPU type
set cpu_type TMS320C5500

# Flash support
set flash_types { 0 1 2 }

# target-side code of flash loader
set FlashLoadSuppCode $mypath/trgcode/flash55.out

# target is big endian
set TargetBigEndian 1

# PC register name
set pc_name PC

# base address of I2C controller in IO space
set i2c0_base 0x3C00

# base address of MCBSP0 in IO space
set mcbsp0_base 0x2800

# base address of MCBSP1 in CPU's IO space
set mcbsp1_base 0x2C00

# Word width (0 - 8 bit, 1 - 16, 2 - 32)
set word_width 1

# base address of EMIF control registers in CPU's IO space
set emif_base 0x0800


###########################################################################
# CPU-specific initialization
###########################################################################
proc CPUSpecificInit { dev } {
                  
  upvar 1 flash_type flash_type

  puts "Resetting and disabling PLL"

  PutShort $dev 0x1C80 2 0x0008
  PutShort $dev 0x1C82 2 0x000B
  PutShort $dev 0x1C88 2 0x0000
  PutShort $dev 0x1C8A 2 0x8000
  PutShort $dev 0x1C8C 2 0x8003
  PutShort $dev 0x1C8E 2 0x8003
  PutShort $dev 0x1C90 2 0x8003
  PutShort $dev 0x1C92 2 0x8003
  PutShort $dev 0x1C98 2 0x0000
  PutShort $dev 0x8400 2 0x0002


  if { $flash_type == 1 } {

    # for EMIF-accessed IC's
    # enable EMIF in XBSR

    puts "Enabling EMIF"

    PutShort $dev 0x6C00 2 [expr 1 | [ReadShort $dev 0x6C00 2]]
    PutShort $dev 0x0800 2 0x0060
    PutShort $dev 0x0801 2 0x0009
    PutShort $dev 0x0804 2 0xFF03
    after 10

  }

}

