#ifdef _TMS320C3x                            

  #define BUF_SIZE 16384
  
  typedef int int32;
  typedef unsigned int uint32;

  /* WARNING!!! int8 & int16 is not correct - really int32 !!! */
  typedef short int16;
  typedef unsigned short uint16;
  typedef char int8;
  typedef unsigned char uint8;

#endif      

#if defined(__TMS320C55X__) || \
    defined(__TMS320C28XX__)

  #if defined(__TMS320C28XX__)
    #if defined(F28335)
      #define BUF_SIZE 32768
	#else
      #define BUF_SIZE 2048
	#endif
	// define "ioport" as dummy
	#define ioport
  #else
    #define BUF_SIZE 8192
  #endif
  
  typedef long int int32;
  typedef unsigned long int uint32;
  typedef short int16;
  typedef unsigned short uint16;

  /* WARNING!!! int8 is not correct - really int16 !!! */
  typedef char int8;
  typedef unsigned char uint8;
  
#endif      

#if defined(__TMS470__) || \
	defined(_TMS320C6X)

  #define ioport

  #if defined(__TMS470__)
    #define BUF_SIZE 2048
  #else
    #if defined(__L138__)
      #define BUF_SIZE 131072
	#else
      #define BUF_SIZE 49152
	#endif
  #endif
  
  typedef int int32;
  typedef unsigned int uint32;
  typedef short int16;
  typedef unsigned short uint16;
  typedef char int8;
  typedef unsigned char uint8;
  
#endif      

/* Buffer for page receive */
#define RCVBUF_SIZE 512 

#define min(x,y) (((x)<=(y))?(x):(y))

#define STATUS_OK                0               
#define STATUS_BAD_COMMAND       1     
#define STATUS_UNEXP_NAK         2
#define STATUS_VERIFY_ERR        3
#define STATUS_FLASHTYPE_ERR     4          
#define STATUS_FLASH_TIMEOUT     5
#define STATUS_NOT_IMPLEMENTED   6
#define STATUS_INVALID_PARAMETER 7
#define STATUS_FLASH_DIRTY       8
#define STATUS_FLASH_COMPACTING_FAIL 9
#define STATUS_FLASH_ERASE_FAIL  10
#define STATUS_FLASH_KEY_MISMATCH  11
#define STATUS_FLASH_PROGRAM_FAIL  12
#define STATUS_KEYS_REPROGRAMMING 13
#define STATUS_ADDRESS_ALIGN 14
#define STATUS_LENGTH_ALIGN 15

#define I2C_24xx_EEPROM   0
#define CLASSIC_NOR_FLASH 1
#define SPI_25xx_EEPROM   2
#define INTERNAL_FLASH 3

#define CMD_PROGRAM 1
#define CMD_ERASESECTOR 2


/* HAL */

uint16 GetByte (void* buf, uint16 ofs);
void PutByte (void* buf, uint16 ofs, uint16 byte);
uint32 GetWord(void* buf, uint32 ofs);
uint16 check_iface_params();

/* Common data */
#if defined(_TMS320C3x)
  #pragma DATA_SECTION(buffer, ".buf")
#endif

extern volatile uint32 buffer[BUF_SIZE/4];
extern volatile uint32 rcvbuf[RCVBUF_SIZE/4];

/* common variables */
extern volatile uint32 command;        /* Command code */
extern volatile uint32 status;         /* Status of operation */
extern volatile uint32 address;        /* Address for operation */
extern volatile uint32 length;         /* Length of data in buffer */
extern volatile uint32 pagelen;        /* Sector or page size of IC */
extern volatile uint32 sectorlen;		/* Sector size for some flash types */
extern volatile uint32 flash_type;     /* Type of IC */
extern volatile uint32 flash_subtype;  /* Subtype of IC */
extern volatile uint32 width;          /* width of IC's data 0 - 8 bit; 1 - 16 bit */
extern volatile uint32 buffer_size;    /* PC-read-only buffer size */
extern volatile uint32 iftype;	       /* 0 - external data bus; 1 - I2C; 2 - MCBSP in SPI mode */
extern volatile uint32 ctrlr_base;     /* Base address of controller, by which communication with 
                                          flash are performed in CPU's address space */
extern volatile uint32 flash_size;     /* Flash size*/
extern volatile uint32 fProgKeys;       /* set to 0x12345678 to enable flash keys programming */

/* classic flash interface specific */
extern volatile uint32 dbus_shift;     /* Position of first bit of IC's dbus on CPU dbus*/
extern volatile uint32 base_address;   /* Start address of IC in CPU's address spase */
extern volatile uint32 cmd_offsets[2]; /* Offsets for even and odd commands */
extern volatile uint32 xbus_width;     /* Width of external memory interface */
extern volatile uint32 word_width;     /* Width of one word of data per one CPU address */

/* Common variables for serial EEPROM's */
extern volatile uint32 c_addr_bytes;   /* count of address bytes for serial EEPROM */

/* I2C EEPROM interface specific */
extern volatile uint32 i2c_addr;       /* I2C Address byte */
extern volatile uint32 i2c_addr_mask;  /* mask for P0..Pn bits in I2C address field */

/* SPI FLASH & EEPROM interface specific */
extern volatile uint32 cs_port_address;  /* Address of port with CS signal */
extern volatile uint32 cs_port_mempage;  /* Memory page of port (CODE/DATA/IO)*/
extern volatile uint32 cs_port_width;    /* Width of port */
extern volatile uint32 cs_port_bit;      /* bit mask of bit */
extern volatile uint32 cs_port_polarity; /* polarity of CS signal. 0 - ~bit drives active level, 1 - bit */

/* Internal flash specific */
#if defined(__TMS470__)|| \
    defined(__TMS320C28XX__)

extern volatile uint32 sectors;         /* Count of sectors */
extern volatile uint32 sector_def[32];  /* sector/bank table. High 8 bytes - bank, low 24 - size of sector*/
extern volatile uint32 flsh_passwd[4];   /* Password for flash programming enable */

#define SECTOR_SIZE(secdef_entry) ((secdef_entry) & 0xFFFFFF)
#define FLASH_BANK(secdef_entry) (((secdef_entry) >> 24) & 0xFF)

#endif

